@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2011 by Barry A. Warsaw
+# Copyright (C) 1998-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.bounce
 #
@@ -32,14 +32,14 @@ __all__ = [
 import re
 
 from email.message import Message
-from cStringIO import StringIO
-from zope.interface import implements
+from io import BytesIO
+from zope.interface import implementer
 
 from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
 
 
-acre = re.compile(r'<(?P<addr>[^>]*)>')
+acre = re.compile(b'<(?P<addr>[^>]*)>')
 
 
 
@@ -57,11 +57,10 @@ def find_textplain(msg):
 
 
 
+@implementer(IBounceDetector)
 class GroupWise:
     """Parse Novell GroupWise and NTMail bounces."""
 
-    implements(IBounceDetector)
-
     def process(self, msg):
         """See `IBounceDetector`."""
         if msg.get_content_type() != 'multipart/mixed' or not msg['x-mailer']:
@@ -71,13 +70,13 @@ class GroupWise:
         text_plain = find_textplain(msg)
         if text_plain is None:
             return NoFailures
-        body = StringIO(text_plain.get_payload())
+        body = BytesIO(text_plain.get_payload(decode=True))
         for line in body:
             mo = acre.search(line)
             if mo:
                 addresses.add(mo.group('addr'))
-            elif '@' in line:
-                i = line.find(' ')
+            elif b'@' in line:
+                i = line.find(b' ')
                 if i == 0:
                     continue
                 if i < 0:
